@@ -4,24 +4,28 @@ use strict;
 use warnings;
 use Module::Load '';
 
-our $VERSION = '4.15.0';
+our $VERSION = '4.16.0';
 sub version { return $VERSION }
 sub sysname { 'bouncehammer'  }
 sub libname { 'Sisimai'       }
 
 sub make {
     # Wrapper method for parsing mailbox or Maildir/
-    # @param    [String] argvs  Path to mbox or Maildir/
-    # @return   [Array]         Parsed objects
-    # @return   [Undef]         Undef if the argument was wrong or an empty array
+    # @param         [String] argv0      Path to mbox or Maildir/
+    # @param         [Hash]   argv1      Parser options
+    # @options argv1 [Integer] delivered 1 = Including "delivered" reason
+    # @return        [Array]             Parsed objects
+    # @return        [Undef]             Undef if the argument was wrong or an empty array
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv0 = shift // return undef;
+    my $argv1 = { @_ };
 
     require Sisimai::Mail;
-    my $mail = Sisimai::Mail->new( $argvs );
+    my $mail = Sisimai::Mail->new( $argv0 );
     my $mesg = undef;
     my $data = undef;
     my $list = [];
+    my $opts = { 'delivered' => $argv1->{'delivered'} // 0 };
 
     return undef unless $mail;
     require Sisimai::Data;
@@ -31,7 +35,7 @@ sub make {
         # Read and parse each mail file
         $mesg = Sisimai::Message->new( 'data' => $r );
         next unless defined $mesg;
-        $data = Sisimai::Data->make( 'data' => $mesg );
+        $data = Sisimai::Data->make( 'data' => $mesg, %$opts );
         push @$list, @$data if scalar @$data;
     }
 
@@ -41,12 +45,15 @@ sub make {
 
 sub dump {
     # Wrapper method to parse mailbox/Maildir and dump as JSON
-    # @param    [String] path   Path to mbox or Maildir/
-    # @return   [String]        Parsed data as JSON text
+    # @param         [String]  argv0     Path to mbox or Maildir/
+    # @param         [Hash]    argv1     Parser options
+    # @options argv1 [Integer] delivered 1 = Including "delivered" reason
+    # @return        [String]            Parsed data as JSON text
     my $class = shift;
     my $argv0 = shift // return undef;
+    my $argv1 = { @_ };
 
-    my $parseddata = __PACKAGE__->make( $argv0 ) // [];
+    my $parseddata = __PACKAGE__->make( $argv0, %$argv1 ) // [];
     my $jsonobject = undef;
 
     # Dump as JSON
@@ -56,6 +63,33 @@ sub dump {
     return $jsonobject->encode( $parseddata );
 }
 
+sub engine {
+    # Parser engine list (MTA/MSP modules)
+    # @return   [Hash]     Parser engine table
+    my $class = shift;
+    my $names = [ 'MTA', 'MSP', 'ARF', 'RFC3464', 'RFC3834' ];
+    my $table = {};
+
+    for my $e ( @$names ) {
+        my $r = 'Sisimai::'.$e;
+        Module::Load::load $r;
+
+        if( $e eq 'MTA' || $e eq 'MSP' ) {
+            # Sisimai::MTA or Sisimai::MSP
+            for my $ee ( @{ $r->index } ) {
+                # Load and get the value of "description" from each module
+                my $rr = sprintf( "Sisimai::%s::%s", $e, $ee );
+                Module::Load::load $rr;
+                $table->{ $rr } = $rr->description;
+            }
+        } else {
+            # Sisimai::ARF, Sisimai::RFC3464, and Sisimai::RFC3834
+            $table->{ $r } = $r->description;
+        }
+    }
+    return $table;
+}
+
 1;
 __END__
 
@@ -79,7 +113,7 @@ Japanese) and MAI (acronym of "Mail Analyzing Interface").
 
 =head1 BASIC USAGE
 
-=head2 C<B<make(I<'/path/to/mbox'>)>>
+=head2 C<B<make(I<'/path/to/mbox'>, I<delivered => 1>)>>
 
 C<make> method provides feature for getting parsed data from bounced email 
 messages like following.
@@ -112,7 +146,12 @@ messages like following.
         printf "%s\n", $json->encode( $v );
     }
 
-=head2 C<B<dump(I<'/path/to/mbox'>)>>
+If you want to get bounce records which reason is "delivered", set "delivered"
+option to make() method like the following:
+
+    my $v = Sisimai->make('/path/to/mbox', 'delivered' => 1);
+
+=head2 C<B<dump(I<'/path/to/mbox'>, I<delivered => 1>)>>
 
 C<dump> method provides feature to get parsed data from bounced email as JSON.
 
@@ -120,6 +159,17 @@ C<dump> method provides feature to get parsed data from bounced email as JSON.
     my $v = Sisimai->dump('/path/to/mbox'); # or Path to Maildir
     print $v;                               # JSON string
 
+=head2 C<B<engine()>>
+
+C<engine> method provides table including parser engine list and its description.
+
+    use Sisimai;
+    my $v = Sisimai->engine();
+    for my $e ( keys %$v ) {
+        print $e;           # Sisimai::MTA::Sendmail
+        print $v->{ $e };   # V8Sendmail: /usr/sbin/sendmail
+    }
+
 =head1 SEE ALSO
 
 =over
