@@ -99,8 +99,22 @@ sub new {
         'diagnostictype', 'deliverystatus', 'reason', 'lhost', 'rhost', 
         'smtpcommand', 'feedbacktype', 'action', 'softbounce',
     );
-    $thing->{ $_ } =  $argvs->{ $_ } // '' for @v1;
-    $thing->{'replycode'}  = Sisimai::SMTP::Reply->find( $argvs->{'diagnosticcode'} );
+    $thing->{ $_ } = $argvs->{ $_ } // '' for @v1;
+    if( $thing->{'action'} =~ m/\A(.+?) .+/ ) {
+        # Action: expanded (to multi-recipient alias)
+        $thing->{'action'} = $1;
+    }
+
+    $thing->{'replycode'} = Sisimai::SMTP::Reply->find( $argvs->{'diagnosticcode'} );
+
+    if( length $thing->{'deliverystatus'} && length $thing->{'replycode'} ) {
+        # Check both of the first digit of "deliverystatus" and "replycode"
+        my $d1 = substr( $thing->{'deliverystatus'}, 0, 1 );
+        my $r1 = substr( $thing->{'replycode'}, 0, 1 );
+
+        # The first digits did not match: 5.1.1 250
+        $thing->{'replycode'} = '' unless $d1 eq $r1;
+    }
     $thing->{'softbounce'} = 1 if $thing->{'replycode'} =~ m/\A4/;
 
     return bless( $thing, __PACKAGE__ );
@@ -121,6 +135,7 @@ sub make {
     return undef unless $argvs->{'data'}->rfc822;
 
     require Sisimai::SMTP;
+    my $delivered1 = $argvs->{'delivered'} // 0;
     my $messageobj = $argvs->{'data'};
     my $rfc822data = $messageobj->rfc822;
     my $fieldorder = { 'recipient' => [], 'addresser' => [] };
@@ -168,7 +183,10 @@ sub make {
             'diagnostictype' => $e->{'spec'}         // '',
             'deliverystatus' => $e->{'status'}       // '',
         };
-        next if $p->{'deliverystatus'} =~ m/\A2[.]/;
+        unless( $delivered1 ) {
+            # Skip if the value of "deliverystatus" begins with "2." such as 2.1.5
+            next if $p->{'deliverystatus'} =~ m/\A2[.]/;
+        }
 
         EMAIL_ADDRESS: {
             # Detect email address from message/rfc822 part
@@ -185,14 +203,6 @@ sub make {
             # Fallback: Get the sender address from the header of the bounced
             # email if the address is not set at loop above.
             $p->{'addresser'} ||= $messageobj->{'header'}->{'to'}; 
-
-            if( $p->{'alias'} && Sisimai::RFC5322->is_emailaddress( $p->{'alias'} ) ) {
-                # Alias address should be the value of "recipient", Replace the
-                # value of recipient with the value of "alias".
-                my $w = $p->{'recipient'};
-                $p->{'recipient'} = $p->{'alias'};
-                $p->{'alias'} = $w;
-            }
         }
         next unless $p->{'addresser'};
         next unless $p->{'recipient'};
@@ -295,7 +305,6 @@ sub make {
             # Check the value of SMTP command
             $p->{'smtpcommand'} = '' unless $p->{'smtpcommand'} =~ $rxcommands;
         }
-
         $o = __PACKAGE__->new( %$p );
         next unless defined $o;
 
@@ -438,6 +447,11 @@ including Sisimai::Data objects.
         }
     }
 
+If you want to get bounce records which reason is "delivered", set "delivered"
+option to make() method like the following:
+
+    my $data = Sisimai::Data->make( 'data' => $mesg, 'delivered' => 1 );
+
 =head1 INSTANCE METHODS
 
 =head2 C<B<damn()>>
