@@ -7,17 +7,17 @@ use MIME::QuotedPrint ();
 
 sub is_mimeencoded {
     # Check that the argument is MIME-Encoded string or not
-    # @param    [String] argvs  String to be checked
+    # @param    [String] argv1  String to be checked
     # @return   [Integer]       0: Not MIME encoded string
     #                           1: MIME encoded string
     my $class = shift;
-    my $argvs = shift || return 0;
+    my $argv1 = shift || return 0;
 
-    return undef unless ref $argvs;
-    return undef unless ref $argvs eq 'SCALAR';
-    $$argvs =~ y/"//d;
+    return undef unless ref $argv1;
+    return undef unless ref $argv1 eq 'SCALAR';
+    $$argv1 =~ y/"//d;
 
-    return 1 if $$argvs =~ m{[\s\t]*=[?][-_0-9A-Za-z]+[?][BbQq][?].+[?]=\s*\z};
+    return 1 if $$argv1 =~ m{[ \t]*=[?][-_0-9A-Za-z]+[?][BbQq][?].+[?]=[ \t]*\z};
     return 0;
 }
 
@@ -40,8 +40,8 @@ sub mimedecode {
 
     for my $e ( @$argvs ) {
         # Check and decode each element
-        $e =~ s/\A\s+//g;
-        $e =~ s/\s+\z//g;
+        $e =~ s/\A[ \t]+//g;
+        $e =~ s/[ \t]+\z//g;
         $e =~ y/"//d;
 
         if( __PACKAGE__->is_mimeencoded( \$e ) ) {
@@ -86,22 +86,52 @@ sub mimedecode {
     return $utf8decoded1;
 }
 
+sub qprintd {
+    # Decode MIME Quoted-Printable Encoded string
+    # @param    [String] argv1   MIME Encoded text
+    # @return   [String]         MIME Decoded text
+    my $class = shift;
+    my $argv1 = shift // return undef;
+
+    return undef unless ref $argv1;
+    return undef unless ref $argv1 eq 'SCALAR';
+    return MIME::QuotedPrint::decode( $$argv1 );
+}
+
+sub base64d {
+    # Decode MIME BASE64 Encoded string
+    # @param    [String] argv1   MIME Encoded text
+    # @return   [String]         MIME-Decoded text
+    my $class = shift;
+    my $argv1 = shift // return undef;
+    my $plain = undef;
+
+    return undef unless ref $argv1;
+    return undef unless ref $argv1 eq 'SCALAR';
+
+    if( $$argv1 =~ m|([+/=0-9A-Za-z\r\n]+)| ) {
+        # Decode BASE64
+        $plain = MIME::Base64::decode( $1 );
+    }
+    return $plain;
+}
+
 sub boundary {
     # Get boundary string
-    # @param    [String]  argvs The value of Content-Type header
+    # @param    [String]  argv1 The value of Content-Type header
     # @param    [Integer] start -1: boundary string itself
     #                            0: Start of boundary
     #                            1: End of boundary
     # @return   [String] Boundary string
     my $class = shift;
-    my $argvs = shift || return undef;
+    my $argv1 = shift || return undef;
     my $start = shift // -1;
     my $value = '';
 
-    if( $argvs =~ m/\bboundary=([^ ]+)/ ) {
+    if( $argv1 =~ m/\bboundary=([^ ]+)/ ) {
         # Content-Type: multipart/mixed; boundary=Apple-Mail-5--931376066
         # Content-Type: multipart/report; report-type=delivery-status;
-	    #    boundary="n6H9lKZh014511.1247824040/mx.example.jp"
+        #    boundary="n6H9lKZh014511.1247824040/mx.example.jp"
         $value =  $1;
         $value =~ y/"'//d;
     }
@@ -136,22 +166,38 @@ Sisimai::MIME is MIME Utilities for C<Sisimai>.
 
 =head1 CLASS METHODS
 
-=head2 C<B<is_mimeencoded( I<Scalar Reference> )>>
+=head2 C<B<is_mimeencoded(I<Scalar Reference>)>>
 
 C<is_mimeencoded()> returns that the argument is MIME-Encoded string or not.
 
     my $e = '=?utf-8?B?55m954yr44Gr44KD44KT44GT?=';
     my $v = Sisimai::MIME->is_mimeencoded( \$e );  # 1
 
-=head2 C<B<mimedecode( I<Array-Ref> )>>
+=head2 C<B<mimedecode(I<Array-Ref>)>>
 
 C<mimedecode()> is a decoder method for getting the original string from MIME
-Encoded string.
+Encoded string in email headers.
 
     my $r = '=?utf-8?B?55m954yr44Gr44KD44KT44GT?=';
     my $v = Sisimai::MIME->mimedecode( [ $r ] );
 
-=head2 C<B<boundary( I<String> )>>
+=head2 C<B<base64d(I<\String>)>>
+
+C<base64d> is a decoder method for getting the original string from MIME Base564
+encoded string.
+
+    my $r = '44Gr44KD44O844KT';
+    my $v = Sisimai::MIME->base64d(\$r);
+
+=head2 C<B<qprintd(I<\String>)>>
+
+C<qprintd> is a decoder method for getting the original string from MIME Quoted-
+printable encoded string.
+
+    my $r = '=4e=65=6b=6f';
+    my $v = Sisimai::MIME->qprintd(\$r);
+
+=head2 C<B<boundary(I<String>)>>
 
 C<boundary()> returns a boundary string from the value of Content-Type header.
 
@@ -168,8 +214,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
