@@ -15,9 +15,7 @@ my $Re1 = {
 };
 
 my $ReFailure = {
-    'expired' => qr{
-        delivery[ ]retry[ ]timeout[ ]exceeded
-    }x,
+    'expired' => qr/delivery[ ]retry[ ]timeout[ ]exceeded/x,
 };
 
 my $Indicators = __PACKAGE__->INDICATORS;
@@ -52,10 +50,6 @@ sub scan {
     my $mbody = shift // return undef;
 
     return undef unless defined $mhead->{'x-gmx-antispam'};
-    if( 0 ) {
-        return undef unless $mhead->{'from'}    =~ $Re0->{'from'};
-        return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
-    }
 
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
@@ -177,9 +171,9 @@ sub scan {
     for my $e ( @$dscontents ) {
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
 
         $e->{'diagnosis'} =~ s{\\n}{ }g;
@@ -193,7 +187,7 @@ sub scan {
         }
 
         $e->{'status'} =  Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
-        $e->{'spec'} ||= 'SMTP';
+        $e->{'spec'}   = 'SMTP';
         $e->{'agent'}  = __PACKAGE__->smtpagent;
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
@@ -242,7 +236,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
