@@ -28,9 +28,9 @@ my $ReFailure = {
         )
     }x,
     'hostunknown' => qr{DNS[ ]Error:[ ](?:
-             Domain[ ]name[ ]not[ ]found
-            |DNS[ ]server[ ]returned[ ]answer[ ]with[ ]no[ ]data
-            )
+         Domain[ ]name[ ]not[ ]found
+        |DNS[ ]server[ ]returned[ ]answer[ ]with[ ]no[ ]data
+        )
     }x,
 };
 
@@ -185,7 +185,6 @@ sub scan {
     return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
 
     require Sisimai::Address;
-
     my $dscontents = []; push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
     my @hasdivided = split( "\n", $$mbody );
     my $rfc822next = { 'from' => 0, 'to' => 0, 'subject' => 0 };
@@ -193,7 +192,6 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-    my $softbounce = 0;     # (Integer) 1 = Soft bounce
     my $statecode0 = 0;     # (Integer) The value of (state *) in the error message
     my $v = undef;
 
@@ -267,9 +265,9 @@ sub scan {
                     $v = $dscontents->[ -1 ];
                 }
 
-                my $r = Sisimai::Address->s3s4( $1 );
-                if( Sisimai::RFC5322->is_emailaddress( $r ) ) {
-                    $v->{'recipient'} = $r;
+                my $addr0 = Sisimai::Address->s3s4( $1 );
+                if( Sisimai::RFC5322->is_emailaddress( $addr0 ) ) {
+                    $v->{'recipient'} = $addr0;
                     $recipients++;
                 }
 
@@ -296,23 +294,23 @@ sub scan {
             if( $e->{'diagnosis'} =~ m/[ \t]+by[ \t]+([^ ]+)[.][ \t]+\[(\d+[.]\d+[.]\d+[.]\d+)\][.]/ ) {
                 # Google tried to deliver your message, but it was rejected by # the server 
                 # for the recipient domain example.jp by mx.example.jp. [192.0.2.153].
-                my $x = $1;
-                my $y = $2;
-                if( $x =~ m/[-0-9a-zA-Z]+[.][a-zA-Z]+\z/ ) {
+                my $hostname = $1;
+                my $ipv4addr = $2;
+                if( $hostname =~ m/[-0-9a-zA-Z]+[.][a-zA-Z]+\z/ ) {
                     # Maybe valid hostname
-                    $e->{'rhost'} = $x;
+                    $e->{'rhost'} = $hostname;
                 } else {
                     # Use IP address instead
-                    $e->{'rhost'} = $y;
+                    $e->{'rhost'} = $ipv4addr;
                 }
             }
         }
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
-            my $r = $mhead->{'received'};
-            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
-            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+            my $r0 = $mhead->{'received'};
+            $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r0->[0] ) };
+            $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r0->[-1] ) };
         }
 
         $statecode0 = $1 if( $e->{'diagnosis'} =~ m/[(]state[ ](\d+)[)][.]/ );
@@ -330,7 +328,6 @@ sub scan {
                 last;
             }
         }
-
         $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
 
         if( $e->{'reason'} ) {
@@ -393,7 +390,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
