@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'contenterror' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          improper[ ]use[ ]of[ ]8-bit[ ]data[ ]in[ ]message[ ]header
         |message[ ](?:
@@ -27,11 +27,18 @@ sub match {
         )
     }xi;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
-sub true { return undef };
+sub true { 
+    # Rejected email due to header format of the email
+    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @return   [Integer]               1: rejected due to content error
+    #                                   0: is not content error
+    # @see      http://www.ietf.org/rfc/rfc2822.txt
+    return undef;
+}
 
 1;
 __END__
@@ -55,7 +62,7 @@ This class is called only Sisimai::Reason class.
 This is the error that a destination mail server has rejected email due to 
 header format of the email like the following. Sisimai will set C<contenterror>
 to the reason of email bounce if the value of Status: field in a bounce email 
-is C<5.6.*>.
+is "5.6.*".
 
 =over 
 
@@ -97,8 +104,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
