@@ -6,15 +6,15 @@ use warnings;
 sub text  { 'exceedlimit' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
-    my $regex = qr/message too large/;
+    my $argv1 = shift // return undef;
+    my $regex = qr/message too large/i;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -35,12 +35,12 @@ sub true {
     return undef unless length $statuscode;
     return 1 if $argvs->reason eq $reasontext;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
     my $diagnostic = $argvs->diagnosticcode // '';
     my $v = 0;
 
-    if( Sisimai::RFC3463->reason( $statuscode ) eq $reasontext ) {
-        # Delivery status code points C<exceedlimit>.
+    if( Sisimai::SMTP::Status->name( $statuscode ) eq $reasontext ) {
+        # Delivery status code points "exceedlimit".
         # Status: 5.2.3
         # Diagnostic-Code: SMTP; 552 5.2.3 Message size exceeds fixed maximum message size
         $v = 1;
@@ -114,8 +114,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
