@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'securityerror' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          authentication[ ](?:
              failed;[ ]server[ ].+[ ]said:  # Postfix
@@ -35,18 +35,25 @@ sub match {
                 my[ ]list[ ]of[ ]allowed[ ]rcpthosts
         |the[ ]message[ ]was[ ]rejected[ ]because[ ]it[ ]contains[ ]prohibited[ ]
             virus[ ]or[ ]spam[ ]content
-        |TLS[ ]required[ ]but[ ]not[ ]supported # SendGrid|the recipient mailserver does not support TLS or have a valid certificate
+        |TLS[ ]required[ ]but[ ]not[ ]supported # SendGrid:the recipient mailserver does not support TLS or have a valid certificate
         |You[ ]have[ ]exceeded[ ]the[ ]the[ ]allowable[ ]number[ ]of[ ]posts[ ]
             without[ ]solving[ ]a[ ]captcha
         |verification[ ]failure
         )
     }ix;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
-sub true { return undef };
+sub true {
+    # The bounce reason is security error or not
+    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @return   [Integer]               1: is security error
+    #                                   0: is not security error
+    # @see http://www.ietf.org/rfc/rfc2822.txt
+    return undef;
+}
 
 1;
 __END__
@@ -102,8 +109,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
