@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'systemerror' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          can[']t[ ]create[ ]user[ ]output[ ]file
         |Internal[ ](?:
@@ -39,11 +39,18 @@ sub match {
         )
     }ix;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
-sub true { return undef };
+sub true {
+    # The bounce reason is system error or not
+    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @return   [Integer]               1: is system error
+    #                                   0: is not system error
+    # @see http://www.ietf.org/rfc/rfc2822.txt
+    return undef;
+}
 
 1;
 __END__
@@ -96,8 +103,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
