@@ -26,9 +26,7 @@ my $SMTPErrorSet = {
         },
         {
             'reason' => 'suspend',
-            'regexp' => [
-                qr/The email account that you tried to reach is disabled[.]/,
-            ],
+            'regexp' => [ qr/The email account that you tried to reach is disabled[.]/ ],
         },
     ],
     'X.2.2' => [
@@ -266,8 +264,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
